#' Clear the external installation directory
#'
#' Clear the external installation directory by removing old Miniconda instances or environments
#' installed for different versions of \pkg{basilisk} with the same middle version number
#' (i.e., same Bioconductor release).
#'
#' @param path String containing the path to the latest version of the directory of interest.
#'
#' @details
#' \code{clearObsoleteDir} can also be applied to the output of \code{\link{getEnvironmentDir}},
#' as the package version is also suffixed onto those directory paths.
#' This is useful for clearing out obsolete versions of package environments.
#'
#' @return 
#' For \code{clearExternalDir}, all Miniconda instances (and associated environments) of the same Bioconductor release as the current \pkg{basilisk} installation are destroyed.
#'
#' The same applies for \code{clearObsoleteDir} except that the Miniconda instance generated by the latest \pkg{basilisk} installation is retained.
#'
#' @author Aaron Lun
#'
#' @seealso
#' \code{\link{getExternalDir}}, which determines the location of the external directory.
#'
#' @seealso
#' \code{\link{installMiniconda}}, for the motivation behind this function.
#'
#' @examples
#' # We can't actually run clearExternalDir() here, as it 
#' # relies on basilisk already being installed.
#' print("dummy test to pass BiocCheck")
#'
#' @export
clearExternalDir <- function() {
    host <- getExternalDir()
    .destroy_major_analogues(host, save=FALSE)
}

#' @export
#' @rdname clearExternalDir
clearObsoleteDir <- function(path=getExternalDir()) {
    .destroy_major_analogues(path, save=TRUE)
}

.destroy_major_analogues <- function(path, save) {
    major.v <- sub("\\.[0-9]+$", "", basename(path))
    all.candidates <- list.files(dirname(path), full.names=TRUE, pattern=paste0("^", major.v))

    if (save) {
        # Not using setdiff to avoid problems with path 
        # normalization on - you guessed it! - Windows.
        keep <- basename(all.candidates) != basename(path) 
        all.candidates <- all.candidates[keep]
    }

    unlink(all.candidates, recursive=TRUE, force=TRUE)
}
